SELECT toDateTime64('1969-12-31 18:00:12', 0, 'America/Phoenix');
SELECT toDateTime64('1969-12-30 18:00:12', 0, 'America/Phoenix');
SELECT toDateTime64('1969-12-31 18:00:12', 0, 'Asia/Istanbul');
